==> cerebro-scripts-0.0.7.tgz: package/scripts/start.js <==
'use strict';

// Makes the script crash on unhandled rejections instead of silently
// ignoring them. In the future, promise rejections that are not handled will
// terminate the Node.js process with a non-zero exit code.
process.on('unhandledRejection', err => {
  throw err;
});

const spawn = require('cross-spawn')
const path = require('path')
const fs = require('fs')

const paths = require('../config/paths')

const appName = process.argv[2] === 'dev' ? 'Electron' : 'Cerebro'

const homeDir = require('os').homedir()

const pluginName = path.basename(paths.pluginPath)

let symlinkPath

if (process.platform === 'darwin') {
  symlinkPath = path.join(
    homeDir,
    'Library',
    'Application Support',
    appName,
    'plugins',
    'node_modules',
    pluginName
  )
} else if (process.platform === 'win32') {
  symlinkPath = path.join(
    process.env.APPDATA,
    appname,
    'plugins',
    'node_modules',
    pluginName
  )
} else {
  symlinkPath = path.join(
    homeDir,
    '.config',
    appName,
    'plugins',
    'node_modules',
    pluginName
  )
}

console.log('Start plugin development')
if (fs.existsSync(symlinkPath)) {
  console.log('   Symlink already exist')
  removeSymlink()
}

console.log('   Create symlink')
fs.symlinkSync(paths.pluginPath, symlinkPath)

// Handle ctrl+c to remove symlink to plugin
process.on('SIGHUP', removeSymlink);
process.on('SIGINT', removeSymlink);
process.on('SIGTERM', removeSymlink);
process.on('SIGBREAK', removeSymlink);


console.log('   Starting webpack...')
const result = spawn.sync(
  paths.webpackBin, 
  ['--config', paths.webpackConfig, '--watch'],
  { stdio: 'inherit' }
)

function removeSymlink() {
  console.log('   Removing symlink')
  fs.unlinkSync(symlinkPath)
}

==> cerebro-scripts-0.0.23.tgz: package/scripts/start.js <==
'use strict';

// Makes the script crash on unhandled rejections instead of silently
// ignoring them. In the future, promise rejections that are not handled will
// terminate the Node.js process with a non-zero exit code.
process.on('unhandledRejection', err => {
  throw err;
});

const spawn = require('cross-spawn')
const path = require('path')
const fs = require('fs')

const paths = require('../config/paths')

const appName = process.argv[2] === 'dev' ? 'Electron' : 'Cerebro'

const homeDir = require('os').homedir()

const pluginName = require(path.join(paths.pluginPath, 'package.json')).name

let symlinkPath

if (process.platform === 'darwin') {
  symlinkPath = path.join(
    homeDir,
    'Library',
    'Application Support',
    appName,
    'plugins',
    'node_modules',
    pluginName
  )
} else if (process.platform === 'win32') {
  symlinkPath = path.join(
    process.env.APPDATA,
    appName,
    'plugins',
    'node_modules',
    pluginName
  )
} else {
  symlinkPath = path.join(
    homeDir,
    '.config',
    appName,
    'plugins',
    'node_modules',
    pluginName
  )
}

console.log('Start plugin development')
if (fs.existsSync(symlinkPath)) {
  console.log('   Symlink already exist')
  removeSymlink()
}

console.log('   Create symlink')
fs.symlinkSync(paths.pluginPath, symlinkPath, process.platform === 'win32' ? 'junction' : 'file')

// Handle ctrl+c to remove symlink to plugin
process.on('SIGHUP', removeSymlink);
process.on('SIGINT', removeSymlink);
process.on('SIGTERM', removeSymlink);
process.on('SIGBREAK', removeSymlink);


console.log('   Starting webpack...')
const result = spawn.sync(
  paths.webpackBin, 
  ['--config', paths.webpackConfig, '--watch'],
  { stdio: 'inherit' }
)

function removeSymlink() {
  console.log('   Removing symlink')
  fs.unlinkSync(symlinkPath)
}
